@@ -1,9 +1,10 @@
 # coding=utf-8
 import json
 import os
+import sys
 
 search = True
-buff = os.getcwd()
+buff = sys.path[0]
 while search:
     if buff[-1] != '/':
         buff += '/'
